package betterquesting.api2.client.gui.controls.io;

import betterquesting.api.utils.RenderUtils;
import betterquesting.api2.client.gui.controls.IValueIO;
import net.minecraft.util.MathHelper;

/* loaded from: betterquesting_api2_client_gui_controls_io.jar:betterquesting/api2/client/gui/controls/io/FloatSimpleIO.class */
public class FloatSimpleIO implements IValueIO<Float> {
    private boolean lerp;
    private float lerpSpd;
    private boolean clamp;
    private final float min;
    private final float max;
    protected float v;
    protected float s;
    private long t;

    public FloatSimpleIO() {
        this(0.0f, 0.0f, 1.0f);
    }

    public FloatSimpleIO(float startVal, float min, float max) {
        this.lerp = false;
        this.lerpSpd = 0.02f;
        this.clamp = true;
        this.v = startVal;
        this.s = startVal;
        this.min = min;
        this.max = max;
        this.t = System.currentTimeMillis();
    }

    public FloatSimpleIO setClamp(boolean enable) {
        this.clamp = enable;
        return this;
    }

    public FloatSimpleIO setLerp(boolean enable, float speed) {
        this.lerp = enable;
        this.lerpSpd = speed;
        return this;
    }

    /* renamed from: readValue, reason: merged with bridge method [inline-methods] */
    public Float m1readValue() {
        if (!this.lerp || this.s == this.v) {
            return Float.valueOf(this.v);
        }
        if (Math.abs(this.s - this.v) < 0.001f) {
            this.s = this.v;
            return Float.valueOf(this.v);
        }
        long d = System.currentTimeMillis() - this.t;
        this.s = RenderUtils.lerpFloat(this.s, this.v, (float) MathHelper.func_151237_a(d * this.lerpSpd, 0.0d, 1.0d));
        if (d > 0) {
            this.t = System.currentTimeMillis();
        }
        return Float.valueOf(this.s);
    }

    public void writeValue(Float value) {
        if (this.s == this.v) {
            this.t = System.currentTimeMillis();
        }
        this.v = this.clamp ? MathHelper.func_76131_a(value.floatValue(), this.min, this.max) : value.floatValue();
    }

    /* renamed from: readValueRaw, reason: merged with bridge method [inline-methods] */
    public Float m0readValueRaw() {
        return Float.valueOf(this.v);
    }

    public void writeValueRaw(Float value) {
        this.v = this.clamp ? MathHelper.func_76131_a(value.floatValue(), this.min, this.max) : value.floatValue();
        this.s = this.v;
    }
}
